@@ -37,7 +37,7 @@ setGeneric("rowVarDiffs", function(x, rows = NULL, cols = NULL, na.rm = FALSE, d
 )
 
 .matrixStats_rowVarDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L, trim = 0, ..., useNames = NA){
-  matrixStats::rowVarDiffs(x, rows = rows, cols = cols, na.rm = na.rm, diff = diff, trim = trim, ..., useNames = useNames)
+  matrixStats::rowVarDiffs(x, rows = rows, cols = cols, na.rm = na.rm, diff = diff, trim = trim, ..., useNames = !isFALSE(useNames))
 }
 
 #' @export
@@ -58,7 +58,7 @@ setGeneric("colVarDiffs", function(x, rows = NULL, cols = NULL, na.rm = FALSE, d
 )
 
 .matrixStats_colVarDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L, trim = 0, ..., useNames = NA){
-  matrixStats::colVarDiffs(x, rows = rows, cols = cols, na.rm = na.rm, diff = diff, trim = trim, ..., useNames = useNames)
+  matrixStats::colVarDiffs(x, rows = rows, cols = cols, na.rm = na.rm, diff = diff, trim = trim, ..., useNames = !isFALSE(useNames))
 }
 
 #' @export
